@@ -112,15 +112,17 @@ pub fn set_open_files_limit(mut _new_limit: isize) -> bool {
             if _new_limit > max {
                 _new_limit = max;
             }
-            if let Ok(ref mut x) = unsafe { sys::system::REMAINING_FILES.lock() } {
-                // If files are already open, to be sure that the number won't be bigger when those
-                // files are closed, we subtract the current number of opened files to the new
-                // limit.
-                let diff = max.saturating_sub(**x);
-                **x = _new_limit.saturating_sub(diff);
-                true
-            } else {
-                false
+            unsafe {
+                if let Ok(ref mut x) = sys::system::REMAINING_FILES.lock() {
+                    // If files are already open, to be sure that the number won't be bigger when those
+                    // files are closed, we subtract the current number of opened files to the new
+                    // limit.
+                    let diff = max.saturating_sub(**x);
+                    **x = _new_limit.saturating_sub(diff);
+                    true
+                } else {
+                    false
+                }
             }
         } else {
             false
